summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/2610intf.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/2610intf.cpp')
-rw-r--r--src/devices/sound/2610intf.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/devices/sound/2610intf.cpp b/src/devices/sound/2610intf.cpp
index 03c3fc218a2..2f6e3e08620 100644
--- a/src/devices/sound/2610intf.cpp
+++ b/src/devices/sound/2610intf.cpp
@@ -62,18 +62,18 @@ void ym2610_device::timer_handler(int c,int count,int clock)
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void ym2610_device::stream_generate(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym2610_device::stream_generate(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
ym2610_update_one(m_chip, outputs, samples);
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void ym2610b_device::stream_generate(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym2610b_device::stream_generate(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
ym2610b_update_one(m_chip, outputs, samples);
}
@@ -102,7 +102,7 @@ void ym2610_device::device_start()
m_timer[1] = timer_alloc(1);
/* stream system initialize */
- m_stream = machine().sound().stream_alloc(*this,0,2,rate, stream_update_delegate(&ym2610_device::stream_generate,this));
+ m_stream = machine().sound().stream_alloc_legacy(*this,0,2,rate, stream_update_legacy_delegate(&ym2610_device::stream_generate,this));
if (!has_configured_map(0) && !has_configured_map(1))
{
@@ -62,18 +62,18 @@ void ym2610_device::timer_handler(int c,int count,int clock)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------
@@ -62,18 +62,18 @@ void ym2610_device::timer_handler(int c,int count,int clock)
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------